.. _source:


.. raw:: html

     <br>

.. title:: Source


**Skull, Bones and Number (OTP-CR-117/19)**

.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.broker		list of bots
    sbn.command		commands
    sbn.default         default values
    sbn.errors		exceptions
    sbn.event           event
    sbn.locate          find objects
    sbn.modules         usercode
    sbn.object          clean namespace
    sbn.parser          parse cli
    sbn.reactor         reactor
    sbn.repeat          repeater
    sbn.run             runtime
    sbn.storage         directory
    sbn.thread          threads
    sbn.timer           anytime
    sbn.utils           utilities


**MODULES**


.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.modules.cmd 	list of commands
    sbn.modules.dbg     raises an exception
    sbn.modules.err     show errors
    sbn.modules.log	log text
    sbn.modules.irc     internet realy chat
    sbn.modules.log     log text
    sbn.modules.req	request
    sbn.modules.rss	rich site syndicate
    sbn.modules.tdo	todo list
    sbn.modules.thr	list threads
